@@ -27,17 +27,7 @@
 #include <glib.h>
 #include <time.h>
 
-typedef enum {
-	GNOME_KEYRING_RESULT_OK,
-	GNOME_KEYRING_RESULT_DENIED,
-	GNOME_KEYRING_RESULT_NO_KEYRING_DAEMON,
-	GNOME_KEYRING_RESULT_ALREADY_UNLOCKED,
-	GNOME_KEYRING_RESULT_NO_SUCH_KEYRING,
-	GNOME_KEYRING_RESULT_BAD_ARGUMENTS,
-	GNOME_KEYRING_RESULT_IO_ERROR,
-	GNOME_KEYRING_RESULT_CANCELLED,
-	GNOME_KEYRING_RESULT_KEYRING_ALREADY_EXISTS
-} GnomeKeyringResult;
+#include "gnome-keyring-result.h"
 
 #define GNOME_KEYRING_RESULT_ALREADY_EXISTS \
 	GNOME_KEYRING_RESULT_KEYRING_ALREADY_EXISTS
@@ -50,6 +40,7 @@ typedef enum {
 	GNOME_KEYRING_ITEM_GENERIC_SECRET = 0,
 	GNOME_KEYRING_ITEM_NETWORK_PASSWORD,
 	GNOME_KEYRING_ITEM_NOTE,
+	GNOME_KEYRING_ITEM_CHAINED_KEYRING_PASSWORD,
 	
 	/*< private >*/
 	GNOME_KEYRING_ITEM_LAST_TYPE,
